==> haskell-profunctors-5.2.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.2.1
id: profunctors-5.2.1-3RBMRXw3iASK8u62NP30RE
key: profunctors-5.2.1-3RBMRXw3iASK8u62NP30RE
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors
category: Control, Categories
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda
abi: 86070f5ceec2c3bf4486b37130d22ceb
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/profunctors-5.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/profunctors-5.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/profunctors-5.2.1
hs-libraries: HSprofunctors-5.2.1-3RBMRXw3iASK8u62NP30RE
depends:
    base-4.10.1.0 base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4
    bifunctors-5.5-GboNfSLJ1zC9Dfov5rQDF7
    comonad-5.0.2-5FGZALTgAAwCV8EmXasfw1
    contravariant-1.4-7z11WOqE85DGeP9JdLBkE1
    distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4=fb09ffe63c021a5df200f5dd3f288699
             bifunctors-5.5-GboNfSLJ1zC9Dfov5rQDF7=a23bc8cb341fa6d1c849977cfff3c9c1
             comonad-5.0.2-5FGZALTgAAwCV8EmXasfw1=c9494ddd8dca169177efbeae2d54ce78
             contravariant-1.4-7z11WOqE85DGeP9JdLBkE1=229249a7c431fe44ea9abf1ace1931a4
             distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE=4194008627baa63a29bcee90329e8d22
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.2.1-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.2.1
id: profunctors-5.2.1-Hp7LyR3VUeW8aUVgI1rbWe
key: profunctors-5.2.1-Hp7LyR3VUeW8aUVgI1rbWe
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors
category: Control, Categories
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda
abi: 0772b0dee3d3cc612fd03b69882154c7
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/profunctors-5.2.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/profunctors-5.2.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/profunctors-5.2.1
hs-libraries: HSprofunctors-5.2.1-Hp7LyR3VUeW8aUVgI1rbWe
depends:
    base-4.10.1.0 base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4
    bifunctors-5.5-I5NPfEm1YkfLL7OlGNPVHa
    comonad-5.0.2-67G8BMs6LFz6dJ7VDIgjn7
    contravariant-1.4.1-13GQTLKwlDGjgc4QL8uyp
    distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 transformers-0.5.2.0
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4=fb09ffe63c021a5df200f5dd3f288699
             bifunctors-5.5-I5NPfEm1YkfLL7OlGNPVHa=e4edeaa04d6b3dd94fb35ab43ef20c35
             comonad-5.0.2-67G8BMs6LFz6dJ7VDIgjn7=0063667ef86b76b37034d670448e46aa
             contravariant-1.4.1-13GQTLKwlDGjgc4QL8uyp=d03fb164c8034777ff5b0827082d2495
             distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE=4194008627baa63a29bcee90329e8d22
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
